"""Models Module
==============
This module contains the definition of simulation models
"""
